==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Mirëfilltësimit i mbaroi koha</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disku është i zënë, s’mund të montohet</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disku është i zënë, s’mund të nxirret</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Pajisja është e zënë, s’mund të nxirret tani</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Pajisja është e zënë, s’mund të hiqet tani</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Vëllim %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>I panjohur</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Pajisja s’u hoq në mënyrë të parrezik</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Herës tjetër klikoni mbi “Hiqe Në Mënyrë të Parrezik” dhe mandej shkëputeni</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">Pajisja është e zënë, s’mund të nxirret tani</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">Pajisja është e zënë, s’mund të hiqet tani</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Nuk çmontohet dot pajisja</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disku është montuar nga përdoruesi &quot;%1&quot;, s’mund ta çmontoni.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>S’gjendet pajisje e montuar</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disqe</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Hap</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Nxirri krejt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Pajisja u hoq në mënyrë të parrezik</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Hyrja u mohua</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>S’keni leje të hyni te kjo dosje</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Po skanohet pajisja, të ndalet?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Ndale</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.9.2.orig.tar.xz: dde-file-manager-5.9.2/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>Mirëfilltësimit i mbaroi koha</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>Disku është i zënë, s’mund të çmontohet tani</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>Disku është i zënë, s’mund të nxirret</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>Pajisja është e zënë, s’mund të nxirret tani</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>Pajisja është e zënë, s’mund të hiqet tani</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>Vëllim %1</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>I panjohur</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>dde-file-manager</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>Pajisja s’u hoq në mënyrë të parrezik</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>Herës tjetër klikoni mbi “Hiqe Në Mënyrë të Parrezik” dhe mandej shkëputeni</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>Nuk çmontohet dot pajisja</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>Disku është montuar nga përdoruesi &quot;%1&quot;, s’mund ta çmontoni.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>S’gjendet pajisje e montuar</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>Disqe</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Disk</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Hap</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>Nxirri krejt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>Pajisja u hoq në mënyrë të parrezik</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>Hyrja u mohua</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>S’keni leje të hyni te kjo dosje</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>Po skanohet pajisja, të ndalet?</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>Ndale</translation>
    </message>
</context>
</TS>
